==> com.liferay.layout.content.page.editor.web-1.0.52.jar: META-INF/resources/js/components/content/CreateContentForm.es.js <==
Liferay.Loader.define("layout-content-page-editor-web@1.0.52/js/components/content/CreateContentForm.es", ['module', 'exports', 'require', 'frontend-js-web', 'frontend-js-metal-web$metal-soy', 'frontend-js-metal-web$metal-state', '../../store/ConnectedComponent.es', './CreateContentForm.soy'], function (module, exports, require) {
  var define = undefined;
  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports["default"] = exports.CreateContentForm = exports.ConnectedCreateContentForm = void 0;

  var _frontendJsWeb = require("frontend-js-web");

  var _metalSoy = _interopRequireDefault(require("frontend-js-metal-web$metal-soy"));

  var _metalState = require("frontend-js-metal-web$metal-state");

  var _ConnectedComponent = _interopRequireDefault(require("../../store/ConnectedComponent.es"));

  var _CreateContentForm = _interopRequireDefault(require("./CreateContentForm.soy"));

  function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : { "default": obj };
  }

  function _typeof(obj) {
    if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
      _typeof = function _typeof(obj) {
        return typeof obj;
      };
    } else {
      _typeof = function _typeof(obj) {
        return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
      };
    }return _typeof(obj);
  }

  function _slicedToArray(arr, i) {
    return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _nonIterableRest();
  }

  function _nonIterableRest() {
    throw new TypeError("Invalid attempt to destructure non-iterable instance");
  }

  function _iterableToArrayLimit(arr, i) {
    var _arr = [];var _n = true;var _d = false;var _e = undefined;try {
      for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) {
        _arr.push(_s.value);if (i && _arr.length === i) break;
      }
    } catch (err) {
      _d = true;_e = err;
    } finally {
      try {
        if (!_n && _i["return"] != null) _i["return"]();
      } finally {
        if (_d) throw _e;
      }
    }return _arr;
  }

  function _arrayWithHoles(arr) {
    if (Array.isArray(arr)) return arr;
  }

  function _classCallCheck(instance, Constructor) {
    if (!(instance instanceof Constructor)) {
      throw new TypeError("Cannot call a class as a function");
    }
  }

  function _defineProperties(target, props) {
    for (var i = 0; i < props.length; i++) {
      var descriptor = props[i];descriptor.enumerable = descriptor.enumerable || false;descriptor.configurable = true;if ("value" in descriptor) descriptor.writable = true;Object.defineProperty(target, descriptor.key, descriptor);
    }
  }

  function _createClass(Constructor, protoProps, staticProps) {
    if (protoProps) _defineProperties(Constructor.prototype, protoProps);if (staticProps) _defineProperties(Constructor, staticProps);return Constructor;
  }

  function _possibleConstructorReturn(self, call) {
    if (call && (_typeof(call) === "object" || typeof call === "function")) {
      return call;
    }return _assertThisInitialized(self);
  }

  function _assertThisInitialized(self) {
    if (self === void 0) {
      throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
    }return self;
  }

  function _getPrototypeOf(o) {
    _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) {
      return o.__proto__ || Object.getPrototypeOf(o);
    };return _getPrototypeOf(o);
  }

  function _inherits(subClass, superClass) {
    if (typeof superClass !== "function" && superClass !== null) {
      throw new TypeError("Super expression must either be null or a function");
    }subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } });if (superClass) _setPrototypeOf(subClass, superClass);
  }

  function _setPrototypeOf(o, p) {
    _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) {
      o.__proto__ = p;return o;
    };return _setPrototypeOf(o, p);
  }

  /**
   * CreateContentForm
   */
  var CreateContentForm =
  /*#__PURE__*/
  function (_PortletBase) {
    _inherits(CreateContentForm, _PortletBase);

    function CreateContentForm() {
      _classCallCheck(this, CreateContentForm);

      return _possibleConstructorReturn(this, _getPrototypeOf(CreateContentForm).apply(this, arguments));
    }

    _createClass(CreateContentForm, [{
      key: "syncGetContentStructuresURL",

      /**
       * @inheritdoc
       * @review
       */
      value: function syncGetContentStructuresURL() {
        var _this = this;

        if (this.getContentStructuresURL) {
          this._structures = null;
          this.fetch(this.getContentStructuresURL).then(function (response) {
            return response.json();
          }).then(function (response) {
            _this._structures = response;
          });
        }
      }
      /**
       * @param {Event} event
       */

    }, {
      key: "_handleFormChange",
      value: function _handleFormChange(event) {
        var form = event.delegateTarget;

        var _form$elements$namedI = _slicedToArray(form.elements.namedItem('ddmStructure').selectedOptions, 1),
            ddmStructureOption = _form$elements$namedI[0];

        this._formValid = form.checkValidity();
        this.emit('formChanged', {
          ddmStructure: {
            id: ddmStructureOption.value,
            label: ddmStructureOption.innerText
          },
          title: form.elements.namedItem('title').value,
          valid: this._formValid
        });
      }
    }]);

    return CreateContentForm;
  }(_frontendJsWeb.PortletBase);
  /**
   * State definition.
   * @review
   * @static
   * @type {!Object}
   */

  exports.CreateContentForm = CreateContentForm;
  CreateContentForm.STATE = {
    /**
     * @default true
     * @instance
     * @memberof CreateContentForm
     * @private
     * @review
     * @type {boolean}
     */
    _formValid: _metalState.Config.bool().internal().value(true),

    /**
     * List of available structure types
     * @default null
     * @instance
     * @memberOf CreateContentForm
     * @private
     * @review
     * @type {Array<{
     *   id: !string,
     *   label: !string
     * }>}
     */
    _structureTypes: _metalState.Config.arrayOf(_metalState.Config.shapeOf({
      id: _metalState.Config.string().required(),
      label: _metalState.Config.string().required()
    })).internal().value([{
      id: 'existing',
      label: Liferay.Language.get('existing-structure')
    }]),

    /**
     * List of available structures
     * @default null
     * @instance
     * @memberOf CreateContentForm
     * @private
     * @review
     * @type {Array<{
     *   id: !string,
     *   label: !string
     * }>}
     */
    _structures: _metalState.Config.arrayOf(_metalState.Config.shapeOf({
      id: _metalState.Config.string().required(),
      label: _metalState.Config.string().required()
    })).internal().value(null),

    /**
     * Selected structure ID
     * @default ''
     * @instance
     * @memberOf CreateContentForm
     * @private
     * @review
     * @type {string}
     */
    selectedStructureId: _metalState.Config.string().value('')
  };
  var ConnectedCreateContentForm = (0, _ConnectedComponent["default"])(CreateContentForm, ['getContentStructuresURL', 'portletNamespace']);
  exports.ConnectedCreateContentForm = ConnectedCreateContentForm;

  _metalSoy["default"].register(ConnectedCreateContentForm, _CreateContentForm["default"]);

  var _default = ConnectedCreateContentForm;
  exports["default"] = _default;
  //# sourceMappingURL=CreateContentForm.es.js.map
});
//# sourceMappingURL=CreateContentForm.es.js.map

==> com.liferay.layout.content.page.editor.web-1.0.126.jar: META-INF/resources/js/components/content/CreateContentForm.es.js <==
Liferay.Loader.define("layout-content-page-editor-web@1.0.126/js/components/content/CreateContentForm.es", ['module', 'exports', 'require', 'frontend-js-web', 'frontend-js-metal-web$metal-soy', 'frontend-js-metal-web$metal-state', '../../store/ConnectedComponent.es', './CreateContentForm.soy'], function (module, exports, require) {
  var define = undefined;
  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports["default"] = exports.CreateContentForm = exports.ConnectedCreateContentForm = void 0;

  var _frontendJsWeb = require("frontend-js-web");

  var _metalSoy = _interopRequireDefault(require("frontend-js-metal-web$metal-soy"));

  var _metalState = require("frontend-js-metal-web$metal-state");

  var _ConnectedComponent = _interopRequireDefault(require("../../store/ConnectedComponent.es"));

  var _CreateContentForm = _interopRequireDefault(require("./CreateContentForm.soy"));

  function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : { "default": obj };
  }

  function _typeof(obj) {
    "@babel/helpers - typeof";
    if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
      _typeof = function _typeof(obj) {
        return typeof obj;
      };
    } else {
      _typeof = function _typeof(obj) {
        return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
      };
    }return _typeof(obj);
  }

  function _slicedToArray(arr, i) {
    return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _nonIterableRest();
  }

  function _nonIterableRest() {
    throw new TypeError("Invalid attempt to destructure non-iterable instance");
  }

  function _iterableToArrayLimit(arr, i) {
    if (!(Symbol.iterator in Object(arr) || Object.prototype.toString.call(arr) === "[object Arguments]")) {
      return;
    }var _arr = [];var _n = true;var _d = false;var _e = undefined;try {
      for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) {
        _arr.push(_s.value);if (i && _arr.length === i) break;
      }
    } catch (err) {
      _d = true;_e = err;
    } finally {
      try {
        if (!_n && _i["return"] != null) _i["return"]();
      } finally {
        if (_d) throw _e;
      }
    }return _arr;
  }

  function _arrayWithHoles(arr) {
    if (Array.isArray(arr)) return arr;
  }

  function _classCallCheck(instance, Constructor) {
    if (!(instance instanceof Constructor)) {
      throw new TypeError("Cannot call a class as a function");
    }
  }

  function _defineProperties(target, props) {
    for (var i = 0; i < props.length; i++) {
      var descriptor = props[i];descriptor.enumerable = descriptor.enumerable || false;descriptor.configurable = true;if ("value" in descriptor) descriptor.writable = true;Object.defineProperty(target, descriptor.key, descriptor);
    }
  }

  function _createClass(Constructor, protoProps, staticProps) {
    if (protoProps) _defineProperties(Constructor.prototype, protoProps);if (staticProps) _defineProperties(Constructor, staticProps);return Constructor;
  }

  function _possibleConstructorReturn(self, call) {
    if (call && (_typeof(call) === "object" || typeof call === "function")) {
      return call;
    }return _assertThisInitialized(self);
  }

  function _assertThisInitialized(self) {
    if (self === void 0) {
      throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
    }return self;
  }

  function _getPrototypeOf(o) {
    _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) {
      return o.__proto__ || Object.getPrototypeOf(o);
    };return _getPrototypeOf(o);
  }

  function _inherits(subClass, superClass) {
    if (typeof superClass !== "function" && superClass !== null) {
      throw new TypeError("Super expression must either be null or a function");
    }subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } });if (superClass) _setPrototypeOf(subClass, superClass);
  }

  function _setPrototypeOf(o, p) {
    _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) {
      o.__proto__ = p;return o;
    };return _setPrototypeOf(o, p);
  }

  /**
   * CreateContentForm
   */
  var CreateContentForm = /*#__PURE__*/function (_PortletBase) {
    _inherits(CreateContentForm, _PortletBase);

    function CreateContentForm() {
      _classCallCheck(this, CreateContentForm);

      return _possibleConstructorReturn(this, _getPrototypeOf(CreateContentForm).apply(this, arguments));
    }

    _createClass(CreateContentForm, [{
      key: "syncGetContentStructuresURL",

      /**
       * @inheritdoc
       * @review
       */
      value: function syncGetContentStructuresURL() {
        var _this = this;

        if (this.getContentStructuresURL) {
          this._structures = null;
          this.fetch(this.getContentStructuresURL).then(function (response) {
            return response.json();
          }).then(function (response) {
            _this._structures = response;
          });
        }
      }
      /**
       * @param {Event} event
       */

    }, {
      key: "_handleFormChange",
      value: function _handleFormChange(event) {
        var form = event.delegateTarget;

        var _form$elements$namedI = _slicedToArray(form.elements.namedItem('ddmStructure').selectedOptions, 1),
            ddmStructureOption = _form$elements$namedI[0];

        this._formValid = form.checkValidity();
        this.emit('formChanged', {
          ddmStructure: {
            id: ddmStructureOption.value,
            label: ddmStructureOption.innerText
          },
          title: form.elements.namedItem('title').value,
          valid: this._formValid
        });
      }
    }]);

    return CreateContentForm;
  }(_frontendJsWeb.PortletBase);
  /**
   * State definition.
   * @review
   * @static
   * @type {!Object}
   */

  exports.CreateContentForm = CreateContentForm;
  CreateContentForm.STATE = {
    /**
     * @default true
     * @instance
     * @memberof CreateContentForm
     * @private
     * @review
     * @type {boolean}
     */
    _formValid: _metalState.Config.bool().internal().value(true),

    /**
     * List of available structure types
     * @default null
     * @instance
     * @memberOf CreateContentForm
     * @private
     * @review
     * @type {Array<{
     *   id: !string,
     *   label: !string
     * }>}
     */
    _structureTypes: _metalState.Config.arrayOf(_metalState.Config.shapeOf({
      id: _metalState.Config.string().required(),
      label: _metalState.Config.string().required()
    })).internal().value([{
      id: 'existing',
      label: Liferay.Language.get('existing-structure')
    }]),

    /**
     * List of available structures
     * @default null
     * @instance
     * @memberOf CreateContentForm
     * @private
     * @review
     * @type {Array<{
     *   id: !string,
     *   label: !string
     * }>}
     */
    _structures: _metalState.Config.arrayOf(_metalState.Config.shapeOf({
      id: _metalState.Config.string().required(),
      label: _metalState.Config.string().required()
    })).internal().value(null),

    /**
     * Selected structure ID
     * @default ''
     * @instance
     * @memberOf CreateContentForm
     * @private
     * @review
     * @type {string}
     */
    selectedStructureId: _metalState.Config.string().value('')
  };
  var ConnectedCreateContentForm = (0, _ConnectedComponent["default"])(CreateContentForm, ['getContentStructuresURL', 'portletNamespace']);
  exports.ConnectedCreateContentForm = ConnectedCreateContentForm;

  _metalSoy["default"].register(ConnectedCreateContentForm, _CreateContentForm["default"]);

  var _default = ConnectedCreateContentForm;
  exports["default"] = _default;
  //# sourceMappingURL=CreateContentForm.es.js.map
});
//# sourceMappingURL=CreateContentForm.es.js.map
